
-   ![](https://github.com/DataDog.png?size=40){ width="40" loading=lazy align=left } DataDog/datadog-agent

    ---

    DataDog/datadog-agent#30871

-   ![](https://github.com/Diaoul.png?size=40){ width="40" loading=lazy align=left } Diaoul/subliminal

    ---

    Diaoul/subliminal#1190

-   ![](https://github.com/Homebrew.png?size=40){ width="40" loading=lazy align=left } Homebrew/brew

    ---

    Homebrew/brew#18662

-   ![](https://github.com/Instagram.png?size=40){ width="40" loading=lazy align=left } Instagram/LibCST

    ---

    Instagram/LibCST#1262

-   ![](https://github.com/NLnetLabs.png?size=40){ width="40" loading=lazy align=left } NLnetLabs/unbound

    ---

    NLnetLabs/unbound#1204

-   ![](https://github.com/NetApp.png?size=40){ width="40" loading=lazy align=left } NetApp/harvest

    ---

    NetApp/harvest#3247

-   ![](https://github.com/PyO3.png?size=40){ width="40" loading=lazy align=left } PyO3/pyo3

    ---

    PyO3/pyo3#4774

-   ![](https://github.com/adafruit.png?size=40){ width="40" loading=lazy align=left } adafruit/circuitpython

    ---

    adafruit/circuitpython#9785

-   ![](https://github.com/astral-sh.png?size=40){ width="40" loading=lazy align=left } astral-sh/ruff

    ---

    astral-sh/ruff#14844

-   ![](https://github.com/astropy.png?size=40){ width="40" loading=lazy align=left } astropy/astropy

    ---

    astropy/astropy#17315

-   ![](https://github.com/cakephp.png?size=40){ width="40" loading=lazy align=left } cakephp/cakephp

    ---

    cakephp/cakephp#18081

-   ![](https://github.com/curl.png?size=40){ width="40" loading=lazy align=left } curl/curl-for-win

    ---

    curl/curl-for-win@05ca7551743b936656033352be0d796cf56e5c0c

-   ![](https://github.com/curl.png?size=40){ width="40" loading=lazy align=left } curl/curl

    ---

    curl/curl@ba9fe58d4331402a24495618668b2cc8afe9794e

-   ![](https://github.com/danmar.png?size=40){ width="40" loading=lazy align=left } danmar/cppcheck

    ---

    danmar/cppcheck#7044

-   ![](https://github.com/esl.png?size=40){ width="40" loading=lazy align=left } esl/MongooseIM

    ---

    esl/MongooseIM#4435

-   ![](https://github.com/ethereum.png?size=40){ width="40" loading=lazy align=left } ethereum/hevm

    ---

    ethereum/hevm#615

-   ![](https://github.com/girlbossceo.png?size=40){ width="40" loading=lazy align=left } girlbossceo/conduwuit

    ---

    girlbossceo/conduwuit@c6bf8f5ea15a6b963220a1de4bb50a639d0d0696

-   ![](https://github.com/hugovk.png?size=40){ width="40" loading=lazy align=left } hugovk/em-keyboard

    ---

    hugovk/em-keyboard#148

-   ![](https://github.com/hugovk.png?size=40){ width="40" loading=lazy align=left } hugovk/norwegianblue

    ---

    hugovk/norwegianblue#233

-   ![](https://github.com/hugovk.png?size=40){ width="40" loading=lazy align=left } hugovk/pypistats

    ---

    hugovk/pypistats#460

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/argon2-cffi

    ---

    hynek/argon2-cffi#185

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/doc2dash

    ---

    hynek/doc2dash#225

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/environ-config

    ---

    hynek/environ-config#88

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/hatch-fancy-pypi-readme

    ---

    hynek/hatch-fancy-pypi-readme#57

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/pem

    ---

    hynek/pem#100

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/prometheus-async

    ---

    hynek/prometheus-async#70

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/stamina

    ---

    hynek/stamina#81

-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek/structlog

    ---

    hynek/structlog#663

-   ![](https://github.com/marcusvolz.png?size=40){ width="40" loading=lazy align=left } marcusvolz/strava_py

    ---

    marcusvolz/strava_py#53

-   ![](https://github.com/matplotlib.png?size=40){ width="40" loading=lazy align=left } matplotlib/matplotlib

    ---

    matplotlib/matplotlib#29251

-   ![](https://github.com/mne-tools.png?size=40){ width="40" loading=lazy align=left } mne-tools/mne-python

    ---

    mne-tools/mne-python#13011

-   ![](https://github.com/oxc-project.png?size=40){ width="40" loading=lazy align=left } oxc-project/oxc

    ---

    oxc-project/oxc#7844

-   ![](https://github.com/praetorian-inc.png?size=40){ width="40" loading=lazy align=left } praetorian-inc/noseyparker

    ---

    praetorian-inc/noseyparker#228

-   ![](https://github.com/prettytable.png?size=40){ width="40" loading=lazy align=left } prettytable/prettytable

    ---

    prettytable/prettytable#339

-   ![](https://github.com/psf.png?size=40){ width="40" loading=lazy align=left } psf/cachecontrol

    ---

    psf/cachecontrol#345

-   ![](https://github.com/pyca.png?size=40){ width="40" loading=lazy align=left } pyca/service-identity

    ---

    pyca/service-identity#75

-   ![](https://github.com/pylast.png?size=40){ width="40" loading=lazy align=left } pylast/pylast

    ---

    pylast/pylast#465

-   ![](https://github.com/pypa.png?size=40){ width="40" loading=lazy align=left } pypa/pip-audit

    ---

    pypa/pip-audit#851

-   ![](https://github.com/pypi.png?size=40){ width="40" loading=lazy align=left } pypi/stdlib-list

    ---

    pypi/stdlib-list#138

-   ![](https://github.com/pypi.png?size=40){ width="40" loading=lazy align=left } pypi/warehouse

    ---

    pypi/warehouse#16996

-   ![](https://github.com/pytest-dev.png?size=40){ width="40" loading=lazy align=left } pytest-dev/pytest

    ---

    pytest-dev/pytest#13062

-   ![](https://github.com/python-attrs.png?size=40){ width="40" loading=lazy align=left } python-attrs/attrs

    ---

    python-attrs/attrs#1368

-   ![](https://github.com/python-attrs.png?size=40){ width="40" loading=lazy align=left } python-attrs/cattrs

    ---

    python-attrs/cattrs#605

-   ![](https://github.com/python-humanize.png?size=40){ width="40" loading=lazy align=left } python-humanize/humanize

    ---

    python-humanize/humanize#221

-   ![](https://github.com/python-pillow.png?size=40){ width="40" loading=lazy align=left } python-pillow/Pillow

    ---

    python-pillow/Pillow#8526

-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry/cleo

    ---

    python-poetry/cleo#462

-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry/poetry

    ---

    python-poetry/poetry#9895

-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry/poetry-core

    ---

    python-poetry/poetry-core#799

-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry/poetry-plugin-bundle

    ---

    python-poetry/poetry-plugin-bundle#125

-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry/poetry-plugin-export

    ---

    python-poetry/poetry-plugin-export#308

-   ![](https://github.com/python-telegram-bot.png?size=40){ width="40" loading=lazy align=left } python-telegram-bot/python-telegram-bot

    ---

    python-telegram-bot/python-telegram-bot#4606

-   ![](https://github.com/python.png?size=40){ width="40" loading=lazy align=left } python/cpython

    ---

    python/cpython#127749

-   ![](https://github.com/python.png?size=40){ width="40" loading=lazy align=left } python/miss-islington

    ---

    python/miss-islington#705

-   ![](https://github.com/rust-lang.png?size=40){ width="40" loading=lazy align=left } rust-lang/crates.io

    ---

    rust-lang/crates.io#10176

-   ![](https://github.com/rustls.png?size=40){ width="40" loading=lazy align=left } rustls/rustls

    ---

    rustls/rustls#2261

-   ![](https://github.com/rustls.png?size=40){ width="40" loading=lazy align=left } rustls/tokio-rustls

    ---

    rustls/tokio-rustls#96

-   ![](https://github.com/sigstore.png?size=40){ width="40" loading=lazy align=left } sigstore/cosign

    ---

    sigstore/cosign#3959

-   ![](https://github.com/sigstore.png?size=40){ width="40" loading=lazy align=left } sigstore/gitsign

    ---

    sigstore/gitsign#602

-   ![](https://github.com/termcolor.png?size=40){ width="40" loading=lazy align=left } termcolor/termcolor

    ---

    termcolor/termcolor#89

-   ![](https://github.com/tornadoweb.png?size=40){ width="40" loading=lazy align=left } tornadoweb/tornado

    ---

    tornadoweb/tornado#3438

-   ![](https://github.com/ultrajson.png?size=40){ width="40" loading=lazy align=left } ultrajson/ultrajson

    ---

    ultrajson/ultrajson#650

-   ![](https://github.com/vlang.png?size=40){ width="40" loading=lazy align=left } vlang/v

    ---

    vlang/v#22681
